//////////////////////////////////////////////////////////////////////////////
//	Module		: ClsNet.h													//
//	Function	: Base class for all Sensoray Network Smart A/D boards.		//
//	Author		: Jim Lamberson												//
//////////////////////////////////////////////////////////////////////////////

#ifndef DEF_ClsNet
#define DEF_ClsNet

#include "ClsNonStd.h"				// Base class for all non-STDbus Smart A/D boards.

#define MAX_SUBBOARDS		2		// Maximum number of 518's residing on any Net product.
#define BUFSIZE				1500	// Size of transmit/receive message buffers.

//////////////////////////////////////////////////////////////////////////////
// Class declaration.

class ClsNet : public ClsNonStd {
public:
	ClsNet( short ProductID, long IPAdrs, char NumBoards, short NumCh );
	char			InByteDirect		( long Adrs );
	void			OutByteDirect		( long Adrs, char Value );
	bool			NetResetChk			();
	long			NetTimeoutGet		();
	void			NetTimeoutSet		( long msec );
	short			NetVersionGet		();
	short			ProductIDGet		();
protected:
	// OS dependent functions:
	virtual	bool	PacketSend			( char *pBuf, long SndLen, long usec )	= 0;
	virtual	short	PacketReceive		( char *pBuf, short BufLen, long usec )	= 0;
	// OS independent functions:
	bool			ActiveALARM			();
	void			CmdOpen				();
	void			CmdClose			();
	void			CmdResetBoard		();
	unsigned char	CmdStatusFlagsGet	();
	void			DeclareResponse		( short nBytes );
	void			SelectBoard			( short BoardNum );
	void			SelectBoardByChan	( short *Chan );
	void			SelectBoardByGroup	( short *Group );
	void			SendByte			( char val );
private:
	char			AndStatusRegs		();
	void			FetchStatusRegs		();
	void			MsgAppendCmd		( char OpCode );
	void			MsgAppendCmd		( char OpCode, char bVal );
	void			MsgAppendCmd		( char Opcode, short wVal );
	void			MsgAppendCmd		( char OpCode, short wVal, char bVal );
	void			MsgAppendWord		( short value );
	void			MsgAppendREADIO8	( short PortAdrs );
	bool			MsgRcv				();
	long			TryReset			();
	// Storage:
	short		ActiveBasePort;				// Base address of currently addressed 518 sub-board.
	char		ChansPerBoard;				// Number of physical channels per sub-board.
	char		GroupsPerBoard;				// Number of 8-channel groups per sub-board.
	short		BasePort[MAX_SUBBOARDS];	// Base addresses of model 518 daughter boards residing on the Net product.
	short		nRespBytes;					// Number of data bytes expected in Net response (excluding TransactionID).
	short		TransactionID;				// Net transaction ID.
											// Packet transmit buffer:
	char		SndBuf[BUFSIZE];			//   Packet buffer.
	char		*pSndBuf;					//   Next write ptr.
};

#endif // #ifndef DEF_ClsNet
