//////////////////////////////////////////////////////////////////////////////
//	Module		: ClsPci.h													//
//	Function	: Base class for Sensoray PCI Smart A/D boards.				//
//	Author		: Jim Lamberson												//
//	Created		: 04/14/1999												//
//////////////////////////////////////////////////////////////////////////////

#ifndef DEF_ClsPci
#define DEF_ClsPci

#include "ClsNonStd.h"					// Base class declaration.

// PCI product identifier codes:
#define SMAD_VENDORID		0x10B5L		// VendorID for Sensoray Smart A/D boards.
#define SMAD_DEVICEID		0x9050L		// DeviceID for Sensoray Smart A/D boards.
#define SMAD_SUBVENDORID	0x6000L		// SubVendorID for Sensoray Smart A/D boards.
										// SubDeviceID is the Smart A/D model number.

//////////////////////////////////////////////////////////////////////////////
// PCI Smart A/D Base Class
//////////////////////////////////////////////////////////////////////////////

class ClsPci : public ClsNonStd {
public:
	ClsPci( short ProductID, long Adrs, short NumCh );
	// Diagnostics functions that are unimplemented on PCI products:
	char			InByteDirect		( long Adrs)					{ return 0; }
	void			OutByteDirect		( long Adrs, char Value )		{}
protected:
	// OS-dependent functions:
	virtual char	InPortByte	( long Adrs)					= 0;
	virtual void	OutPortByte	( long Adrs, char Val )			= 0;
	virtual void	OutPortDword( long Adrs, long Val )			= 0;
	// OS-independent functions:
	bool			ActiveALARM			();
	void			CmdClose			();
	void			CmdResetBoard		();
	unsigned char	CmdStatusFlagsGet	();
	void			DeclareResponse		( short nBytes );
	void			HandshakeCmdString	();
	void			HandshakeDatString	( short nBytes );
	bool			HandshakeWait		( const char mask, const char xormask, const double maxtime );
	void			SendByte			( char val );
	// Class storage:
	long			IoBase;		// Window to I/O ports inside Actel gate array.
	long			CfgBase;	// PLX9050 Local PCI configuration registers.
	long			MemBase;	// Window to local RAM from E200:E2FF.
};

#endif // #ifndef DEF_ClsPci
